[![DOI](https://zenodo.org/badge/223017290.svg)](https://zenodo.org/badge/latestdoi/223017290)

# Why we cannot decarbonise international conferences without virtual participation
*The travel carbon footprint of the AGU Fall Meeting 2019*

**Milan Klöwer**\
Atmospheric, Oceanic and Planetary Physics, University of Oxford\
*milan.kloewer@physics.ox.ac.uk*

For comments and changes, please raise an [issue](https://github.com/milankl/CarbonFootprintAGU/issues) or create a pull request.

## Summary

More than 24,000 scientists from at least 101 countries will participate in the [American Geoscience Union's (AGU) Fall Meeting 2019](https://www.agu.org/fall-meeting) to be held in San Francisco, USA. 
We estimate that these scientists will travel in total 244 million km to San Francisco and back, which emits 69,300 tCO2e, an average of 2.9 tCO2e per scientist. 
98% of these carbon emissions result from long-haul flights (>1500km). 
Relocating the AGU Fall Meeting to Chicago, a location that is nearly optimal to minimize to total distance covered, would reduce the emissions by 12%.
If the equivalent of the 17% highest emitting attendees participated virtually, the carbon emissions would be reduced by 39%. Virtual participation for 36% of the highest emitting attendees would reduce the carbon footprint by 76%. 
Only a format in which the conference takes place biennially in Chicago with virtual participation for 36% of attendees would reduce the travel carbon footprint by more than 90%.

## 1. Introduction

International aviation is projected to contribute 22% to global greenhouse gas emissions in 2050 [[1](http://www.europarl.europa.eu/RegData/etudes/STUD/2015/569964/IPOL_STU(2015)569964_EN.pdf)], as doubling of passengers is expected by 2036 [[2](https://www.iata.org/pressroom/pr/Pages/2017-10-24-01.aspx)]. 
Although aviation is with 2-3% a minor contributor to global emissions [[3](https://archive.ipcc.ch/pdf/assessment-report/ar5/wg3/ipcc_wg3_ar5_chapter8.pdf)] its distribution is exceptionally unequal. 
Probably only 6% of the world population flies in a given year [[4](https://www.quora.com/What-percent-of-the-worlds-population-will-fly-in-an-airplane-in-their-lives)] and most flights are taken by frequent-flyers [[5](https://www.inequalityintransport.org.uk/)].
Universities and other research institutions are high emitters [[6](https://tyndall.ac.uk/sites/default/files/twp161.pdf)], with individual carbon emissions an order of magnitude larger [[7](https://www.sciencedirect.com/science/article/pii/S0959652619311862)] than the suggested personal carbon allowance [[8](https://wordpress.hotorcool.org/wp-content/uploads/2019/02/15_Degree_Lifestyles_MainReport.pdf), [9](https://iopscience.iop.org/article/10.1088/1748-9326/aa7541/pdf), [10](https://www.sciencedirect.com/science/article/pii/S0969699719303229)]. 
Research-associated carbon emissions are dominated by air travel to conferences, meetings and for fieldwork [[6](https://tyndall.ac.uk/sites/default/files/twp161.pdf)]. 
Recent studies suggest that academic air travel has limited direct link to professional success [[7](https://www.sciencedirect.com/science/article/pii/S0959652619311862), [11](https://www.tandfonline.com/doi/full/10.1080/17450101.2019.1589727)].

Most conferences do not provide live-streaming, nor allow for remote-speaking, although alternatives exist. 
Very few conferences are fully virtual (e.g. [virtual island summit](https://www.islandinnovation.co/summit/)) and therefore often almost carbon neutral [[12](https://hiltner.english.ucsb.edu/index.php/ncnc-guide/)]. 
Continuous virtual seminar series allow for frequent academic exchange (e.g. [Virtual Blue COP 25](https://virtualbluecop25.org/)) sometimes with a focus on field-specific subjects (e.g. [EBUS Webinars](https://ebuswebinars.wixsite.com/ebuswebinars)). 
Live-streaming is provided by more conferences (e.g. [JuliaCon](https://juliacon.org/2019/), with an automatic archive on [YouTube](https://www.youtube.com/playlist?list=PLP8iPy9hna6StY9tIJIUN3F_co9A0zh0H)), mainly to make them more accesible for participants with constraints on time, money, or freedom of travel.

The carbon footprint of most conferences and meetings is dominated by participants with disproportionate travel emissions due to long distance flights [[13](https://dx.doiorg/10.1038/news031208-13),[14](https://dx.doi.org/10.1126/science.318.5847.36)]. 
For the [European Geoscience Union's General Assembly](https://egu2019.eu/) 2012 it was estimated that 20% of the highest emitting participants are responsible for 70% of the travel emissions [[6](https://tyndall.ac.uk/sites/default/files/twp161.pdf)]. Although train journeys are often promoted as a low-carbon alternative, it was shown for the same conference in 2019 that the reduction potential from an increasing number of train journey is at maximum only 10% [[15](https://github.com/milankl/CarbonFootprintEGU)]. 
The travel carbon footprint of the AGU Fall Meeting was critised before [[16](https://doi.org/10.1029/2017EO089361)], and its fly-in culture therefore questioned [[17](https://doi.org/10.1029/2018EO111475)].
Here, we calcuate the travel emissions for the AGU Fall Meeting in 2019 accurately based on the affiliations of all presenting authors. Reduction scenarios are calculated and discussed based on relocation to minimize the total distance covered, and virtual participation.

## 2. Results

More than 24,000 scientists from at least 101 countries will participate in the AGU Fall Meeting 2019 to be held in San Francisco, USA. 
Most scientists come from one of three regions (Fig. 1): North America (around 63%) , East Asia (17%) and Europe (14%). 
In total, 244 million km will be travelled by all attendees to San Francisco and back, which is equivalent to 1.6 [astronomical units](https://en.wikipedia.org/wiki/Astronomical_unit), 1.6 times the distance from Earth to the Sun. 

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/world.png)

*Figure 1: Number of attendees per city of all 24,008 scientists attending the AGU Fall Meeting, illustrated on an equi-distant map, which preserves the distances with respect to San Francisco. The total distance travelled is 244 million km.*

Within the USA, most scientists are based in the [Northeast megalopolis](https://en.wikipedia.org/wiki/Northeast_megalopolis) and in California with additional hotspots around Seattle, Washington; Boulder, Colorado; and in Texas (Fig. 2). 
Every scientist arriving from Colorado and further east has to take a long-haul flight (>1500km) to reach San Francisco.

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/usa.png)

Figure 2: *Number of attendees per city from North America.*

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/europe.png)

Figure 3: *Number of attendees per city from Europe. The map is rotated with the most direct route to San Francisco indicated in the top.*

Analysing the emissions per distance travelled we identify that rail, bus or car journeys (assumed for less than 400km distance to San Francisco) account for less than 0.1% of the total emissions (Fig. 4). 
Short-haul flights (<1500km) account for 2%, wheras long-haul flights (<8000km) for 24% and super long-haul flights (>8000km) for 74% of total emissions. 
Travel journeys of more than 8000km, which are mostly taken by scientists crossing either Pacific or Atlantic, dominate therefore the total travel carbon footprint.

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/emissions_distance.png)

*Figure 4: Travel carbon emissions as a function of distance. The emissions are for retour journeys, whereas the distance is one-way. The distances of the highest 17% (more than 9540km away from San Francisco) and 36% (more than 8145km) emitting attendees are marked. Rail, bus or car journeys account for less than 0.1%, short-haul flights for 2%, long-haul flights for 24% and super long-haul flights for 74% of total emissions.*

The United States are the biggest contributor to the total travel carbon emissions (23%), with Maryland, New York, Massachussets and Texas ranking highest among its states (Fig. 5). 
Scientists from China are responsible for 20%, with average per capita emissions of more than 6 tCO2e. 
Highest per capita emissions (>10tCO2e) have attendees arriving from Reunion (beyond the map limits in Fig. 1), though low numbers make their contribution to the total budget marginal.

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/emissions_country.png)

*Figure 5: Total carbon emissions per country. USA (14222 scientists) and China (2266) are the biggest contributors. The emissions from the USA is split into its states, of which the largest contributors are indicated by state code.*

Sorting the carbon emission per country (or state for the USA) by the per capita emissions from lowest emitting attendees to highest emitting attendees, yields a [Lorenz curve](https://en.wikipedia.org/wiki/Lorenz_curve) describing the carbon emission's inequality (Fig. 6).
A relatively small number of attendees is responsible for a large amount of emissions.
This inequality can be measured with the [Gini coefficient](https://en.wikipedia.org/wiki/Gini_coefficient), which is 46% here.
In the following we will discuss two cases by identifying that (i) the 17% furthest-travelling are responsible for 39% and (ii) the top 36% are responsible for 74% of the conference's total travel carbon footprint. 
Offering a virtual participation of the AGU Fall Meeeting for the equivalent of the top 17% attendees would therefore reduce the total emissions by 39%, assuming that the carbon emissions from virtual participation are negligible. This includes countries like China, Taiwan and India and the African continent.
Virtual participation for the top 36% would reduce the emissions by 74%, which includes almost every country outside of North America.

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/emissions_inequality.png)

*Figure 6: Carbon emissions sorted by highest per capita emissions. Each grey rectangle represents one country or US state, some of the largest in terms of emissions and participants are named. The 36% furthest-travelling AGU attendees (green lines) are responsible for 74% of the conference's total travel carbon footprint, with the top 17% (blue lines) responsible for 39% of the total.*

The AGU Fall Meeting 2018 was held in Washington, DC, following a 2017 conference in New Orleans, Louisiana. 
Assuming the same attendees from 2019 for these two conferences, we can calculate the travel carbon footprint respectively. 
New Orleans as a location for the AGU Fall Meeting has very similar carbon emissions compared to San Francisco, but relocating the conference to Washington, DC, reduces the emissions by 7.6% (Fig. 7). 
Optimizing the conference location with respect to the total distance covered (which is equivalent to minimizing with respect to the total carbon emissions) yields a global minimum in northern Wisconsin. 
The optimal conference location has emissions of 86.5% compared to the 2019 emissions for San Francisco, but is inconvenietly located away from major cities. 
The closest cities are Minneapolis (86.7% of the emissions), Winnipeg (86.9%), and Milwaukee (87.3%). 
As none of them have major international airports and are therefore hard to reach without an additional detour for many attendees, we identify Chicago as a favourable location which would reduce the emissions by 12.3% (see discussion in section [4.6.1](https://github.com/milankl/CarbonFootprintAGU#461-sensitivity-to-assumptions-of-the-optimal-location)). Using Hawaii as a conference location would increase the emissions by 42%.

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/optimal_location.png)

*Figure 7: The optimal location for the AGU Fall Meeting to minimize the total distance travelled. Optimal locations are shown in terms of the carbon emissions relative to San Francisco. White lines enclose areas where the emissions would be below 100% and 90%, as indicated. The optimal location is in northern Wisconsin. Chicago is reasonably close to the optimal location, reduces the emissions by 12% and internationally easily accessible.*

We want to summarize the findings by presenting possible reduction scenarios for the AGU Fall Meeting that could be implemented within the next years (Fig. 8)
Relocating the conference to Washington DC would reduce the travel carbon emissions by 8%. A near-optimal location is Chicago, as the emissions would be reduced by 12%. 
No further reduction potential beyond 12% is possible from relocation, as Chicago is globally the near-optimal location.
Offering virtual participation for the equivalent of the 17% highest emitting attendees would reduce the emissions by 39%.
Conferences like [Ocean Science Meeting](https://www.agu.org/ocean-sciences-meeting/) are only held biennially. 
Adapting such a conference format, which could be combined with a fully virtual conference every other year, reduces the annual carbon emissions by 50%. 
Moving such a biennial format to Chicago yields 56% reduction.
Further reduction scenarios beyond 60% are only possible with virtual participation.
The most progressive conference format, with a reduction beyond 90%, is possible when the AGU Fall Meeting would be held biennially in Chicago with 36% virtual participation for most non-American scientists including remote presenting for orals and poster sessions, live-streaming and digital discussion forums. 

![](https://github.com/milankl/CarbonFootprintAGU/blob/master/plots/reduction_scenarios.png)

*Figure 8: Emission reduction scenarios for the AGU Fall Meeting relative to 2019, represented as annual emissions. A biennial conference format may include a fully virtual conference every other year.*

## 3. Data

Data is based on the abstracts of the scientific programme [published by AGU](https://agu.confex.com/agu/fm19/meetingapp.cgi/Home/0), covering both oral and poster abstracts. We identified the presenting author from all 26,133 abstracts. Of those, we were able to geolocate the affiliations of 24,008 unique presenters. A list of numbers of presenters can be found in [`/data/locations.csv`](https://github.com/milankl/CarbonFootprintAGU/blob/master/data/locations.csv) (per city), [`/data/emissions_per_country.csv`](https://github.com/milankl/CarbonFootprintAGU/blob/master/data/emissions_per_country.csv) (per country), and [`/data/emissions_per_state.csv`](https://github.com/milankl/CarbonFootprintAGU/blob/master/data/emissions_per_state.csv) (per state in the US).

## 4. Methods

All scripts can be found in [`/scripts`](https://github.com/milankl/CarbonFootprintAGU/tree/master/scripts) and the assumptions are discussed in section [4.6](https://github.com/milankl/CarbonFootprintAGU#46-sensitivity-to-assumptions).

## 4.1 Travel route

The departure location per attendee is assumed to be their affiliation's city. The named location `city, state, country` is converted to geographical coordinates with [Nominatim](https://nominatim.org/release-docs/develop/api/Overview/) from the [OpenStreetMap database](https://www.openstreetmap.org/) (see [`/scripts/geocode_locations.py`](https://github.com/milankl/CarbonFootprintAGU/blob/master/scripts/geocode_locations.py)

Every attendee is assumed to travel back to their departure location with the same mode of transport. Due to the lack of data, we have to assume that every scientists only came to San Francisco for the purpose of the AGU Fall Meeting. Some scientists likely connected their journey to San Francisco with other conferences, meetings or holidays.

We assume all journeys to be direct, that means, we calculate the distance as the [great circle distance](https://en.wikipedia.org/wiki/Great-circle_distance). This is more accurate for long-haul than for short-haul, and may have some considerable errors for rail, car or bus (see discussion in section [4.6](https://github.com/milankl/CarbonFootprintAGU#46-sensitivity-to-assumptions).)
  
## 4.4 Mode of transport

Rail, car or bus is assumed for all journeys with distances of less than 400km. Airplanes are assumed for longer distances. Short-haul is defined as distances of less than 1500km, distances up to 8000km are long-haul and longer distance are considered to be super long-haul.

## 4.5 Carbon emissions

The emission of rail, bus or car journeys are grouped and assumed to emit 60gCO2e / km / person.
[[18](http://ecopassenger.hafas.de/hafas-res/download/Ecopassenger_Methodology_Data.pdf),
[19](http://www.cer.be/sites/default/files/publication/Facts%20and%20figures%202014.pdf),
[20](https://www.eea.europa.eu/data-and-maps/indicators/energy-efficiency-and-specific-co2-emissions/energy-efficiency-and-specific-co2-9),
[21](https://dataportal.orr.gov.uk/media/1114/rail-infrastructure-assets-environmental-2017-18.pdf)]

The missions of flights are split into three categories

- 200gCO2e / km / person for short-haul,
- 250gCO2e / km / person for long-haul, and
- 300gCO2e / km / person for super long-haul.

These values take into account factors that typically decrease the per km emissions for long-haul flights such as [[22](https://www.atmosfair.de/wp-content/uploads/atmosfair-flight-emissions-calculator-englisch-1.pdf),
[23](https://www.icao.int/environmental-protection/CarbonOffset/Documents/Methodology%20ICAO%20Carbon%20Calculator_v10-2017.pdf),[24](https://www.myclimate.org/fileadmin/user_upload/myclimate_-_home/01_Information/01_About_myclimate/09_Calculation_principles/Documents/myclimate-flight-calculator-documentation_EN.pdf)]

- increased fuel consumption for take-off
- decreased detour factors for longer flights
- average aircraft types and their fuel consumption
- average passenger load factors for average airlines.

Additionally, we take into account factors that typically increase the per km emissions for longer flights, which on average tend to outweigh the factors from above [[22](https://www.atmosfair.de/wp-content/uploads/atmosfair-flight-emissions-calculator-englisch-1.pdf)]

- increased fuel weight for longer flights
- increased flight altitudes depending on distance covered
- indirect CO2 effects on ozone and cloud formation depending on flight altitude [[25](https://doi.org/10.1007/s11367-018-1556-3)].

Some emission calculators do not include all of the factors above (e.g. [23](https://www.icao.int/environmental-protection/CarbonOffset/Documents/Methodology%20ICAO%20Carbon%20Calculator_v10-2017.pdf) and [24](https://www.myclimate.org/fileadmin/user_upload/myclimate_-_home/01_Information/01_About_myclimate/09_Calculation_principles/Documents/myclimate-flight-calculator-documentation_EN.pdf)). To our knowledge, the atmosfair calculator [[22](https://www.atmosfair.de/wp-content/uploads/atmosfair-flight-emissions-calculator-englisch-1.pdf)] is the most sophisticated. 
It includes the indirect CO2 effects not just as a factor 2, as an approximation recommended by [Jungbluth and Meili, 2019 ([25])](https://doi.org/10.1007/s11367-018-1556-3) but makes this factor flight altitude dependent (as recommended as a next order accuracy therein). 
Additionally, atmosfair's calculator uses a database which analysed the aircraft types, their fuel consumption and passenger loads typically flown on specific routes. We therefore obtained our assumed emissions values by searching for typical flight routes to San Francisco and simplified the results.

We assume economy class for every participant.

Carbon emissions of live-streaming are assumed to be negligible.

## 4.6 Sensitivity to assumptions

Sensitivity to the assumptions is fairly low. Main contributions to the uncertainty of the carbon footprint are

a) **The carbon dioxide equivalent emissions of long-haul and super long-haul flights**. These are assumed to be 250g and 300g CO2e / km / person, respectively, which is a representative average with probably less than 10% error [[17](https://www.atmosfair.de/wp-content/uploads/atmosfair-flight-emissions-calculator-englisch-1.pdf)]. The emissions of individual flights have much higher uncertainty and depend on number of passengers, airline / flight class, type of aircraft, potential detours, flight altitude, and weather conditions. The carbon dioxide equivalent emissions of super long-haul flights (>8,000km) are usually higher due to additional fuel weight and flight altitude, although increased fuel consumption from start and detour contribute less for such long distances.

b) **The exact route travelled by every attendee.** We have to assume great circle distances for every route travelled, although most attendees have to travel to the closest international airport first. Some routes require stopovers at airports that usually come with some detour. It is assumed that these detours rarely add more than 20% to the distance covered. As most attendees arrive from major cities with direct connections to San Francisco, we consider this uncertainty to contribute less than 10% to the total travel carbon footprint.

c) **The carbon dioxide equivalent emissions of rail, bus or car journeys.**
These are assumed to be 60gCO2e / km / person, which we estimate as an average [[13](http://ecopassenger.hafas.de/hafas-res/download/Ecopassenger_Methodology_Data.pdf),
[14](http://www.cer.be/sites/default/files/publication/Facts%20and%20figures%202014.pdf),
[15](https://www.eea.europa.eu/data-and-maps/indicators/energy-efficiency-and-specific-co2-emissions/energy-efficiency-and-specific-co2-9),
[16](https://dataportal.orr.gov.uk/media/1114/rail-infrastructure-assets-environmental-2017-18.pdf)],
due to the lack of data on modes of transport.
Emissions from individual journeys can, however, vary by an order of magnitude depending on the type of bus or car, type of train (electric, diesel, highspeed or regional), the local energy mix (for electric), number of passengers, etc. 
As the contribution of rail, bus or car journeys to the overall carbon footprint of AGU-related travel is negligible (<0.1%), the uncertainty here is negligible too.

### 4.6.1 Sensitivity to assumptions of the optimal location

Analysing the optimal location for the AGU Fall Meeting assumes the same attendees as for the 2019 conference in San Francisco. Relocating comes with an additional pull factor of conferences that are held in vicinity of a scientist's location: 
The data from 2019 likely includes attendees from California that only attend because the conference is held nearby in San Francisco, but which wouldn't attend a conference in Chicago. 
Assuming their attendence therefore yields slightly higher emissions, which results in a slightly larger reduction potential than 12% when relocated to Chicago. 
However, as most of the emissions come from long and super long-haul flights, we estimate this effect to have negligible influence on the exact location that minimises the carbon emissions.

### 5. References

[1] [Cames, M, J Graichen, A Siemons, V Cook, 2015. *Emission Reduction Targets for International Aviation and Shipping*, European Parliament, Policy Department A: Economic and Scientific Policy](http://www.europarl.europa.eu/RegData/etudes/STUD/2015/569964/IPOL_STU(2015)569964_EN.pdf)

[2] [International Air Transport Association, 2017. *20 Year Passenger Forecast*](https://www.iata.org/publications/store/Pages/20-year-passenger-forecast.aspx)

[3] [Sims R., et al.,  2014:  *Transport*.  In:  Climate Change 2014: Mitigation of Climate Change. Contribution of Working Group III to the Fifth Assessment Report of the Intergovernmental Panel on Climate Change, Cambridge University Press, Cambridge, United Kingdom and New York, NY, USA.](https://archive.ipcc.ch/pdf/assessment-report/ar5/wg3/ipcc_wg3_ar5_chapter8.pdf)

[4] [Farrier, T, 2013. *What percent of the world's population will fly in an airplane in their lives?*](https://www.quora.com/What-percent-of-the-worlds-population-will-fly-in-an-airplane-in-their-lives)

[5] [Banister, D, 2018. *Inequality in Transport*, Alexandrine Press.](https://www.inequalityintransport.org.uk/)

[6] [Le Quere, C, et al., 2015. *Towards a culture of low-carbon research for the 21st century*, Tyndall Centre for Climate Change Research, Working paper 161.](https://tyndall.ac.uk/sites/default/files/twp161.pdf)

[7] [Wynes, S, SD Donner, S Tannason, N Nabors, 2019. *Academic air travel has a limited influence on professional success*. **Journal of Cleaner Production**, 226, p. 959-967.](https://www.sciencedirect.com/science/article/pii/S0959652619311862)

[8] [Institute for Global Environmental Strategies, Aalto University, and D-mat ltd. 2019. *1.5-Degree Lifestyles: Targets and Options for Reducing Lifestyle Carbon Footprints*. Technical Report.Institute for Global Environmental Strategies, Hayama, Japan. ](https://wordpress.hotorcool.org/wp-content/uploads/2019/02/15_Degree_Lifestyles_MainReport.pdf)

[9] [Wynes, S and KA Nicholas, 2017. *The climate mitigation gap: education andgovernment recommendations miss the mosteffective individual actions.* **Environ. Res. Lett.**,12,074024.](https://iopscience.iop.org/article/10.1088/1748-9326/aa7541/pdf)

[10] [Goessling, S, P Hanna, J Higham, S Cohen, D Hopkins, 2019. *Can we fly less? Evaluating the ‘necessity’ of air travel*,**Journal of Air Transport Management**, 81](https://www.sciencedirect.com/science/article/pii/S0969699719303229)

[11] [Higham, JES, Hopkins D, Orchiston C, 2019. *The work-sociology of academic aeromobility at remote institutions*, **Mobilities**, 14, p. 612-631](https://www.tandfonline.com/doi/full/10.1080/17450101.2019.1589727)

[12] [Ken Hiltner, 2016. *A Nearly Carbon Neutral Conference Model*](https://hiltner.english.ucsb.edu/index.php/ncnc-guide/)

[13] [Mason, B, 2003. *Scientists contribute to greenhouse-gas emissions*, **Nature News**, doi:10.1038/news031208-13](https://dx.doi.org/10.1038/news031208-13)

[14] [Lester, B, 2007. *Greening the Meeting*. **Science**, 318, 5847, pp. 36-38, doi:10.1126/science.318.5847.36](https://dx.doi.org/10.1126/science.318.5847.36)

[15] [Kloewer, M, 2019. *The Travel Carbon Footprint of the EGU General Assembly 2019*, Zenodo, doi:10.5281/zenodo.3549850.](https://github.com/milankl/CarbonFootprintEGU)

[16] [Parrish, JT, 2017.  *Should AGU Have Fly-in Meetings Anymore?*, **Eos**, 98, doi:10.1029/2017EO089361](https://doi.org/10.1029/2017EO089361).

[17] [Cobb, KM, P Kalmus, DM Romps, 2018. *AGU Should Support Its Members Who Fly Less*, **Eos**, 99, doi:10.1029/2018EO111475](https://doi.org/10.1029/2018EO111475)

[18] [Knoerr, W and R Huettermann, 2016. *EcoPassenger: Environmental Methodology and Data, Update 2016*](http://ecopassenger.hafas.de/hafas-res/download/Ecopassenger_Methodology_Data.pdf)

[19] [International Railway Association UIC and Community  of  European  Railway  and  Infrastructure  Companies CER, 2016. *Rail Transport and Environment: Facts & Figures.*](http://www.cer.be/sites/default/files/publication/Facts%20and%20figures%202014.pdf)

[20] [European Environment Agency EEA, 2017. *Energy efficiency and specific CO2 emissions*](https://www.eea.europa.eu/data-and-maps/indicators/energy-efficiency-and-specific-co2-emissions/energy-efficiency-and-specific-co2-9)

[21] [UK Office of Rail and Road ORR, 2018: *Rail infrastructure, assets and environmental 2017-18 Annual Statistical Release*](https://dataportal.orr.gov.uk/media/1114/rail-infrastructure-assets-environmental-2017-18.pdf)

[22] [Atmosfair, 2016. *atmosfair Flight Emissions Calculator: Documentation of the Method and Data*.](https://www.atmosfair.de/wp-content/uploads/atmosfair-flight-emissions-calculator-englisch-1.pdf)

[23] [International Civil Aviation Organization ICAO, 2017. *ICAO Carbon Emissions Calculator Methodology, Version 10*](https://www.icao.int/environmental-protection/CarbonOffset/Documents/Methodology%20ICAO%20Carbon%20Calculator_v10-2017.pdf)

[24] [Foundation myclimate, 2019. *The myclimate Flight Emission Calculator*.](https://www.myclimate.org/fileadmin/user_upload/myclimate_-_home/01_Information/01_About_myclimate/09_Calculation_principles/Documents/myclimate-flight-calculator-documentation_EN.pdf)

[25] [Jungbluth, N and C Meili, 2019. *Recommendations for calculation of the global warming potential of aviation including the radiative forcing index*. **Int J Life Cycle Assess**, 24, 404](https://doi.org/10.1007/s11367-018-1556-3)

## 6. Acknowledgements

Comments on earlier versions of this manuscript by Soeren Thomsen and Casimir Lavergne (Sorbonne University, Paris) and Jefim Vogel (University of Leeds) are highly appreciated. The [Python](https://www.python.org/), [Numpy](https://numpy.org/), [Matplotlib](https://matplotlib.org/) and [Cartopy](https://scitools.org.uk/cartopy/docs/latest/) communities are gratefully acknowledged for providing software libraries that were used for this analysis.
